/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxPersistencePersistenceUnitVisitor.java 376 2006-04-21 08:22:16Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.annotations.analyzer;

import org.objectweb.easybeans.deployment.annotations.impl.JavaxPersistenceUnit;
import org.objectweb.easybeans.deployment.annotations.metadata.interfaces.IPersistenceUnit;

/**
 * This class manages the handling of &#64;{@link javax.persistence.PersistenceUnit}
 * annotation.
 * @param <T> An implementation of IPersistenceUnit interface.
 * @author Florent Benoit
 */
public class JavaxPersistencePersistenceUnitVisitor<T extends IPersistenceUnit> extends AbsAnnotationVisitor<T> implements
        AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/persistence/PersistenceUnit;";

    /**
     * UnitName attribute of the annotation.
     */
    private static final String UNIT_NAME = "unitName";

    /**
     * Persistence context information.
     */
    private JavaxPersistenceUnit javaxPersistenceUnit = null;

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method or field metadata
     */
    public JavaxPersistencePersistenceUnitVisitor(final T annotationMetadata) {
        super(annotationMetadata);
        javaxPersistenceUnit = new JavaxPersistenceUnit();
    }

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.objectweb.asm.Type}.
     */
    @Override
    public void visit(final String name, final Object value) {
        if (name.equals(UNIT_NAME)) {
            javaxPersistenceUnit.setUnitName((String) value);
        }
    }

    /**
     * Visits the end of the annotation.<br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        // set flag on field
        getAnnotationMetadata().setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
