/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: InvocationParameterTest00.java 310 2006-04-04 06:57:28Z pinheirg $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.base;

import javax.ejb.Interceptors;

import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;
import org.objectweb.easybeans.tests.common.interceptors.invocationcontext.ComplexObject00;
import org.objectweb.easybeans.tests.common.interceptors.invocationcontext.ICParamInterceptorCheckNull;
import org.objectweb.easybeans.tests.common.interceptors.invocationcontext.ICParamInterceptorModifiedParam;
import org.objectweb.easybeans.tests.common.interceptors.invocationcontext.ICParamInterceptorNewArray;
import org.objectweb.easybeans.tests.common.interceptors.invocationcontext.ICParamInterceptorNull;

/**
 * Used to manipulate the invocation context object.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class InvocationParameterTest00 implements ItfInvocationParameter00 {

    /**
     * Logger.
     */
    private JLog logger = JLogFactory.getLog(InvocationParameterTest00.class);

    /**
     * Returns objects passed as parameters with null references. There are two interceptors
     * that set to null the parameters reference.
     * @param objCP complex object
     * @param intValues an integer array
     * @return array with the objects passed as parameters.
     * @throws Exception if a problem occurs.
     */
    @Interceptors({ICParamInterceptorNull.class, ICParamInterceptorCheckNull.class})
    public Object[] getObjects00(ComplexObject00 objCP, Integer[] intValues) throws Exception{
        Object[] arObjs = {objCP, intValues};
        logger.debug("after interceptors, parameters: {0}, {1}", objCP, intValues);
        return arObjs;
    }

    /**
     * Returns objects passed as parameters without modification.There are two interceptors
     * that create a new array to return, but it doesn't modify the objects passed as parameters.
     * @param objCP complex object
     * @param intValues an integer array
     * @return array with the objects passed as parameters.
     * @throws Exception if a problem occurs.
     */
    @Interceptors({ICParamInterceptorNewArray.class, ICParamInterceptorNewArray.class})
    public Object[] getObjects01(ComplexObject00 objCP, Integer[] intValues) throws Exception{
        Object[] arObjs = {objCP, intValues};
        logger.debug("after interceptors, parameters: {0}, {1}", objCP, intValues);
        return arObjs;
    }
 
    /**
     * Returns objects passed as parameters with modifications.
     * There is an interceptor that modifies the parameters.
     * @param objCP complex object
     * @param intValues an integer array
     * @return array with the objects passed as parameters.
     * @throws Exception if a problem occurs.
     */
    @Interceptors({ICParamInterceptorModifiedParam.class})
    public Object[] getObjects02(ComplexObject00 objCP, Integer[] intValues) throws Exception{
        Object[] arObjs = {objCP, intValues};
        logger.debug("after interceptors, parameters: {0}, {1}", objCP, intValues);
        return arObjs;
    }
}
