/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: PrintHelper.java 316 2006-04-04 11:21:20Z pinheirg $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.helper;

import java.util.List;

import javax.ejb.InvocationContext;

import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;

/**
 * This helper is used to do operation with InvocationContext
 * and interceptors.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public final class PrintHelper {

    /**
     * Helper should have a private constructor.
     *
     */
    private PrintHelper(){

    }
    /**
     * Intercepts the method and adds a value in the list that was get from
     * InvocationContext.
     * @param <E> Element Type
     * @param invocationContext contains attributes of invocation, the first
     *        parameter of the intercepted method must be a list.
     * @param value value to add
     * @param className class that is invoking this method.
     * @return method's invocation result
     * @throws Exception if invocation fails
     */
    @SuppressWarnings("unchecked")
    public static <E> Object addValue(final InvocationContext invocationContext, final E value, final String className)
            throws Exception {
        JLog logger = JLogFactory.getLog(PrintHelper.class);

        logger.info("In the addValue of PrinterHelper: order={0}", value);

        Object[] arObj = invocationContext.getParameters();
        // First parameter must be a list
        List<E> arOrder = (List<E>) arObj[0];

        // If can't add, throw an exception to avoid cascade errors.
        if (!arOrder.add(value)) {
            throw new Exception(className + " can't add the value " + value + ".");
        }
        return invocationContext.proceed();
    }

    /**
     * Gets the error msg formatted.
     * @param expected values to a correct answer
     * @param result result values after an execution
     * @param seedMessage standard message to show
     * @return error message
     */
    public static String getPrintOrderErrorMsg(final List expected, final List result, final String seedMessage) {
        String strMessage = seedMessage;

        if (expected == null & result == null) {
            strMessage += " Result=[null], Expected=[null].";
        } else if (expected == null) {
            strMessage += " Result=" + result.toString() + ", Expected=[null].";
        } else if (result == null) {
            strMessage += " Result=[null], Expected=" + expected.toString() + ".";
        } else {
            strMessage += " Actual=" + result.toString() + ", Expected=" + expected.toString() + ".";
        }
        return strMessage;
    }
}
