/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestSLExceptions00.java 360 2006-04-19 07:51:41Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.interceptors.business.stateless.containermanaged;

import static org.objectweb.easybeans.tests.common.helper.EJBHelper.getBeanRemoteInstance;

import org.objectweb.easybeans.tests.common.ejbs.base.ItfExceptions;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.SLSBInterceptorExceptions00;
import org.objectweb.easybeans.tests.common.exception.CustomException00;
import org.objectweb.easybeans.tests.common.exception.CustomException01;
import org.objectweb.easybeans.tests.interceptors.business.base.BaseExceptions00;
import org.testng.annotations.Configuration;
import org.testng.annotations.ExpectedExceptions;
import org.testng.annotations.Test;

/**
 * Verifies if the interceptors and exceptions are working well.
 * @reference JSR220-PROPOSED FINAL - Item:11.3.2
 * @requirement Application Server must be running; all test beans must be
 *              deployed.
 * @setup gets the reference of SLSBInterceptorExceptions00
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class TestSLExceptions00 extends BaseExceptions00{

    /**
     * Gets bean instance used in the tests.
     * @throws Exception if there is a problem with the bean initialization.
     */
    @Configuration(beforeTestMethod = true)
    public void startUp() throws Exception {
        ItfExceptions bean = getBeanRemoteInstance(SLSBInterceptorExceptions00.class, ItfExceptions.class);
        super.setBean(bean);
    }

    /**
     * @see org.objectweb.easybeans.tests.interceptors.business.base.BaseExceptions00
     * @throws Exception if there is a problem with the bean initialization.
     */
    @Override
    @Test(groups = {"Exceptions"})
    @ExpectedExceptions({CustomException00.class})
    public void testException00() throws Exception {
        super.testException00();
    }

    /**
     * @see org.objectweb.easybeans.tests.interceptors.business.base.BaseExceptions00
     * @throws Exception if there is an enhancer exception.
     */
    @Override
    @Test(groups = {"Exceptions"})
    @ExpectedExceptions({CustomException01.class})
    public void testException01() throws Exception {
        super.testException01();
    }

    /**
     * @see org.objectweb.easybeans.tests.interceptors.business.base.BaseExceptions00
     * @throws Exception if there is an enhancer exception.
     */
    @Override
    @Test(groups = {"Exceptions"})
    @ExpectedExceptions({CustomException01.class})
    public void testException02() throws Exception {
        super.testException02();
    }

    /**
     * @see org.objectweb.easybeans.tests.interceptors.business.base.BaseExceptions00
     * @throws Exception if there is an enhancer exception.
     */
    @Override
    @Test(groups = {"Exceptions"})
    @ExpectedExceptions({CustomException00.class, CustomException01.class})
    public void testException03() throws Exception {
        super.testException03();
    }
}
