/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestNeverRemoteSLSB.java 319 2006-04-11 12:07:29Z pinheirg $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.transaction.containermanaged.stateless;

import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.SLSBContainerTransactionNever;
import org.objectweb.easybeans.tests.transaction.containermanaged.base.TestNever;
import org.testng.annotations.Configuration;
import org.testng.annotations.ExpectedExceptions;
import org.testng.annotations.Test;

/**
 * Verifies if the container-managed transaction in the stateless bean is
 * following the JSR220.The items covered in this test are: 12.6.2.6.
 * @reference JSR220-PROPOSED FINAL
 * @requirement Application Server must be running; the bean
 *              org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SLSBContainerTransactionNever
 *              must be deployed.
 * @setup gets the reference of SLSBContainerTransactionNever and binds the
 *        databases specified in the EmbeddedTest.
 * @author Gisele Pinheiro Souza
 * @author Eduardo Studzinski Estima de Castro
 */
public class TestNeverRemoteSLSB extends TestNever {

    /**
     * Creates a new instance of the bean.
     * @throws Exception if a lookup error occurs.
     */
    @Configuration(beforeTestMethod = true)
    public void createBean() throws Exception {
        super.createBean(SLSBContainerTransactionNever.class);
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestNever.
     * @throws Exception if an error during the test startup occurs.
     */
    @Configuration(beforeTestClass = true)
    @Override
    public void setup() throws Exception {
        super.setup();
    }



    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestNever.
     * @throws Exception if an error during the tests occurs.
     */
    @Test(groups = {"never attribute features"})
    @Override
    @ExpectedExceptions(value = javax.ejb.EJBException.class)
    public void testUsingClientTrans() throws Exception {
        super.testUsingClientTrans();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestNever.
     * @exception if an error during the test occurs.
     */
    @Test(groups = {"roll back"})
    @Override
    @ExpectedExceptions(value = java.lang.IllegalStateException.class)
    public void testSetRollbackOnly() throws Exception {
        super.testSetRollbackOnly();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestNever.
     * @exception if an error during the test occurs.
     */
    @Test(groups = {"roll back"})
    @Override
    @ExpectedExceptions(value = java.lang.IllegalStateException.class)
    public void testGetRollbackOnly() throws Exception {
        super.testGetRollbackOnly();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestNever.
     */
    @Configuration(beforeTestMethod = true)
    @Override
    public void deleteTable() {
        super.deleteTable();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestNever.
     * @throws if an error during the tests occurs.
     */
    @Test(groups = {"general attribute features"})
    @Override
    @ExpectedExceptions(value = java.lang.IllegalStateException.class)
    public void testGetUserTransactionWithEJBContext() throws Exception {
        super.testGetUserTransactionWithEJBContext();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestNever.
     * @throws if an error during the tests occurs.
     */
    @Test(groups = {"general attribute features"})
    @Override
    @ExpectedExceptions(value = javax.naming.NameNotFoundException.class)
    public void testGetUserTransactionWithLookup() throws Exception {
        super.testGetUserTransactionWithLookup();
    }

    /**
     * Makes a rollback in the transaction actives.
     * @throws Exception if a transaction exception occurs.
     */
    @Configuration(beforeTestMethod = true)
    @Override
    public void cleanTransaction() throws Exception{
        super.cleanTransaction();
    }
}
